<?php
$lang['expired_searchable'] = 'Artigos expirados podem aparecer nos resultados da pesquisa';
$lang['helpshowall'] = 'Mostrar todos os artigos independentemente da data de vencimento';
$lang['error_invaliddates'] = 'Uma ou mais das datas enviadas est&atilde;o inv&aacute;lidas';
$lang['notify_n_draft_items_sub'] = '%d Artigo(s) de not&iacute;cia';
$lang['notify_n_draft_items'] = 'You have %s that is/are not published';
$lang['unlimited'] = 'Ilimitado';
$lang['none'] = 'Nenhum';
$lang['anonymous'] = 'An&ocirc;nimo';
$lang['unknown'] = 'Desconhecido';
$lang['fesubmit_redirect'] = 'PageID or alias to redirect to after a news article has been submitted via the fesubmit action';
$lang['allow_summary_wysiwyg'] = 'Allow using a WYSIWYG editor on the summary field';
$lang['title_browsecat_template'] = 'Browse Category Template Editor';
$lang['title_browsecat_sysdefault'] = 'Default Browse category Template';
$lang['browsecattemplate'] = 'Browse Category Templates';
$lang['error_filesize'] = 'An uploaded file exceeded the maximum allowed size';
$lang['post_date_desc'] = 'Post Date Descending';
$lang['post_date_asc'] = 'Post Date Ascending';
$lang['expiry_date_desc'] = 'Expiry Date Descending';
$lang['expiry_date_asc'] = 'Expiry Date Ascending';
$lang['title_desc'] = 'Title Descending';
$lang['title_asc'] = 'Title Ascending';
$lang['fesubmit_status'] = 'The status of news articles submitted via the frontend';
$lang['error_invalidfiletype'] = 'N&atilde;o pode enviar este tipo de arquivo';
$lang['error_upload'] = 'Um problema ocorreu ao enviar um arquivo';
$lang['error_movefile'] = 'N&atilde;o foi poss&iacute;vel criar o arquivo: %s';
$lang['error_mkdir'] = 'N&atilde;o foi poss&iacute;vel criar o diret&oacute;rio: %s';
$lang['expiry_interval'] = 'O n&uacute;mero de dias (por padr&atilde;o) antes de um artigo expirar (se expirar estiver selecionado)';
$lang['removed'] = 'Removido';
$lang['msg_contenttype_removed'] = 'The news content type has been removed.  Please place {news} tags with appropriate parameters into your page template or into your page content to replace this functionality.';
$lang['delete_selected'] = 'Delete os artigos selecionados';
$lang['areyousure_deletemultiple'] = 'Voc&ecirc; tem certeza que quer deletas todas estas not&iacute;cias?\nEsta a&ccedil;&atilde;o n&atilde;o pode ser desfeita!';
$lang['error_templatenamexists'] = 'Um template com este nome j&aacute; existe';
$lang['error_noarticlesselected'] = 'Nenhum artigo foi selecionado';
$lang['reassign_category'] = 'Mudar categoria para';
$lang['select'] = 'Selecione';
$lang['approve'] = 'Mude o Status para &#039;Publicado&#039;';
$lang['revert'] = 'Mude o Status para &#039;Rascunho&#039;';
$lang['hide_summary_field'] = 'Hide the summary field when adding or editing articles';
$lang['textbox'] = 'Text Input';
$lang['checkbox'] = 'Checkbox';
$lang['textarea'] = 'Text Area';
$lang['file'] = 'File';
$lang['auto_create_thumbnails'] = 'Automatically create thumbnail files for files with these extensions';
$lang['allowed_upload_types'] = 'Allow only files with these extensions to be uploaded';
$lang['fielddefupdated'] = 'Field Definition Updated';
$lang['editfielddef'] = 'Edit Field Definition';
$lang['up'] = 'Up';
$lang['down'] = 'Down';
$lang['fielddefdeleted'] = 'Field Definition Deleted';
$lang['nameexists'] = 'A field by that name already exists';
$lang['notanumber'] = 'Maximum Length is Not a Number';
$lang['fielddef'] = 'Field Definition';
$lang['fielddefadded'] = 'Field Definition Successfully Added';
$lang['public'] = 'Public';
$lang['type'] = 'Type';
$lang['info_maxlength'] = 'The maximum length only applies to text input fields.';
$lang['maxlength'] = 'Maximum Length';
$lang['addfielddef'] = 'Add Field Definition';
$lang['customfields'] = 'Field Definitions';
$lang['deprecated'] = 'unsupported';
$lang['subject_newnews'] = 'A new News article has been posted';
$lang['email_subject'] = 'The Subject of the outgoing email';
$lang['email_template'] = 'The format of the email message';
$lang['formsubmit_emailaddress'] = 'Email address to receive notification of news submission';
$lang['extra'] = 'Extra';
$lang['uploadscategory'] = 'Uploads Category';
$lang['title_available_templates'] = 'Available Templates';
$lang['resettodefault'] = 'Reset to Factory Defaults';
$lang['title_form_template'] = 'Form Template Editor';
$lang['title_detail_template'] = 'Detail Template Editor';
$lang['title_summary_template'] = 'Summary Template Editor';
$lang['prompt_templatename'] = 'Template Name';
$lang['prompt_template'] = 'Template Source';
$lang['title_form_sysdefault'] = 'Default Form Template';
$lang['title_summary_sysdefault'] = 'Default Summary Template';
$lang['title_detail_sysdefault'] = 'Default Detail Template';
$lang['info_sysdefault2'] = '<strong>Note:</strong> This tab contains text areas to allow you to edit a set of templates that are displayed when you create a &#039;new&#039; summary, detail, or form template.  Changing content in this tab, and clicking &#039;submit&#039; will <strong>not effect any current displays</strong>.';
$lang['info_sysdefault'] = '<em>(the content used by default when a new template is created)</em>';
$lang['template'] = 'Template';
$lang['prompt_name'] = 'Name';
$lang['prompt_default'] = 'Default';
$lang['prompt_newtemplate'] = 'Create A New Template';
$lang['help_pagelimit'] = 'Maximum number of items to display (per page).  If this parameter is not supplied all matching items will be displayed.  If it is, and there are more items available than specified in the pararamter, text and links will be supplied to allow scrolling through the results';
$lang['prompt_page'] = 'P&aacute;gina';
$lang['firstpage'] = '$lt;<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'de';
$lang['prompt_pagelimit'] = 'Limite de P&aacute;gina';
$lang['prompt_sorting'] = 'Ordenar por';
$lang['title_filter'] = 'Filtros';
$lang['published'] = 'Publicado';
$lang['draft'] = 'Rascunho';
$lang['expired'] = 'Expirado';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Restaurar para os padr&otilde;es';
$lang['restoretodefaultsmsg'] = 'Esta opera&ccedil;&atilde;o ir&aacute; restaurar o conte&uacute;do do  Modelo Visual para o padr&atilde;o do sistema. Voc&ecirc; tem certeza que quer prosseguir?';
$lang['addarticle'] = 'Adicionar Artigo';
$lang['articleadded'] = 'O artigo foi adicionado com sucesso.';
$lang['articleupdated'] = 'O artigo foi atualizado com sucesso.';
$lang['articledeleted'] = 'O artigo foi deletado com sucesso.';
$lang['addcategory'] = 'Adicionar Categoria';
$lang['categoryadded'] = 'A categoria foi adicionada com sucesso.';
$lang['categoryupdated'] = 'A categoria foi atualizada com sucesso.';
$lang['categorydeleted'] = 'A categoria foi deletada com sucesso.';
$lang['addnewsitem'] = 'Adicionar Not&iacute;cia';
$lang['allcategories'] = 'Todas Categorias';
$lang['allentries'] = 'Todas Entradas';
$lang['areyousure'] = 'Voc&ecirc; tem certeza que quer deletar?';
$lang['articles'] = 'Artigos';
$lang['cancel'] = 'Cancelar';
$lang['category'] = 'Categoria';
$lang['categories'] = 'Categorias';
$lang['default_category'] = 'Categoria Padr&atilde;o';
$lang['content'] = 'Conte&uacute;do';
$lang['dateformat'] = '%s n&atilde;o est&aacute; em um formato de hora v&aacute;lido (aaaa-mm-dd hh:mm:ss)';
$lang['delete'] = 'Deletar';
$lang['description'] = 'Adicione, edite e remova Not&iacute;cias';
$lang['formtemplate'] = 'Modelo Visual de Formul&aacute;rios';
$lang['detailtemplate'] = 'Modelo Visual Detalhado';
$lang['default_templates'] = 'Modelo Visual Padr&atilde;o';
$lang['detailtemplateupdated'] = 'O modelo visual detalhado foi atualizado com sucesso no banco de dados.';
$lang['displaytemplate'] = 'Exibir Modelo Visual';
$lang['edit'] = 'Editar';
$lang['enddate'] = 'Data Final';
$lang['endrequiresstart'] = 'Ao entrar uma data final, &eacute; preciso entrar uma data inicial tamb&eacute;m';
$lang['entries'] = '%s Entradas';
$lang['status'] = 'Status';
$lang['expiry'] = 'Expira&ccedil;&atilde;o';
$lang['filter'] = 'Filtro';
$lang['more'] = 'Mais';
$lang['category_label'] = 'Categoria:';
$lang['author_label'] = 'Postado por:';
$lang['moretext'] = 'Mais Texto';
$lang['name'] = 'Nome';
$lang['news'] = 'Not&iacute;cias';
$lang['news_return'] = 'Retornar';
$lang['newcategory'] = 'Nova Categoria';
$lang['needpermission'] = 'Voc&ecirc; precisa da permiss&atilde;o &#039;%s&#039; para realizar esta fun&ccedil;&atilde;o.';
$lang['nocategorygiven'] = 'Nenhuma categoria especificada';
$lang['startdatetoolate'] = 'The Start Date is too late (after end date?)';
$lang['nocontentgiven'] = 'Nenhum conte&uacute;do especificado';
$lang['noitemsfound'] = '<strong>Nenhum</strong> item encontrado para a categoria: %s';
$lang['nopostdategiven'] = 'Nenhuma Data de Postagem informada';
$lang['note'] = '<em>Nota:</em> As datas precisam estar no formato &#039;aaaa-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'Nenhum t&iacute;tulo informado';
$lang['nonamegiven'] = 'Nenhum nome informado';
$lang['numbertodisplay'] = 'N&uacute;mero &aacute; exibir (em branco mostra todos os registros)';
$lang['print'] = 'Imprimir';
$lang['postdate'] = 'Data de Postagem';
$lang['postinstall'] = 'Tenha certeza de especificar a permiss&atilde;o de &quot;Modificar Not&iacute;cias&quot; aos usu&aacute;rios que ir&atilde;o administrar os itens de Not&iacute;cias.';
$lang['selectcategory'] = 'Selecione a Categoria';
$lang['showchildcategories'] = 'Exibir sub-categorias';
$lang['sortascending'] = 'Ordena&ccedil;&atilde;o Ascendente';
$lang['startdate'] = 'Data de In&iacute;cio';
$lang['startoffset'] = 'Come&ccedil;ar a exibir a partir do en&eacute;simo item';
$lang['startrequiresend'] = 'Ao entrar uma data inicial, &eacute; preciso entrar uma data final tamb&eacute;m';
$lang['submit'] = 'Enviar';
$lang['summary'] = 'Sum&aacute;rio';
$lang['summarytemplate'] = 'Modelo Visual Resumido';
$lang['summarytemplateupdated'] = 'O modelo visual de not&iacute;cia resumido foi atualizado com sucesso.';
$lang['title'] = 'T&iacute;tulo';
$lang['options'] = 'Op&ccedil;&otilde;es';
$lang['optionsupdated'] = 'As op&ccedil;&otilde;es foram atualizadas com sucesso.';
$lang['useexpiration'] = 'Usar data de expira&ccedil;&atilde;o';
$lang['eventdesc-NewsArticleAdded'] = 'Enviado quando o artigo &eacute; adicionado.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Enviado quando o artigo &eacute; editado.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Enviado quando o artigo &eacute; deletado.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Enviado quando uma categoria &eacute; adicionada.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Enviado quando uma categoria &eacute; editada.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
<li>\&quot;origname\&quot; - The original name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Enviado quando uma categoria &eacute; deletada.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the deleted category </li>
<li>\&quot;name\&quot; - Name of the deleted category</li>
</ul>
';
$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article.';
$lang['helpnumber'] = 'N&uacute;mero m&aacute;ximo de itens a exibir =- deixar em branco mostrar&aacute; todos os itens.';
$lang['helpstart'] = 'Iniciar no en&eacute;simo item -- deixar em branco iniciar&aacute; no primeiro item';
$lang['helpcategory'] = 'S&oacute; mostrar itens para aquela categoria. Use * ap&oacute;s o nome para exibir as subcategorias. Muitas categiras pode ser usadas se separadas por v&iacute;rgula. Deixar em branco, ir&aacute; mostrar todas as categorias.';
$lang['helpmoretext'] = 'Texto para exibir no final de uma not&iacute;cia se ela passar do tamanho m&aacute;ximo do resumo. O Padr&atilde; &eacute; &quot;mais...&quot;';
$lang['helpsummarytemplate'] = 'Usa um modelo visual diferente para exibir o resumo do artigo. Ele deve estar no diret&oacute;rio modules/News/templates.';
$lang['helpformtemplate'] = 'Use a database template for displaying the article submission form. This template must exist and be visible in the form templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpbrowsecattemplate'] = 'Use a database template for displaying the category browser. This template must exist and be visible in the Browse Category Templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
$lang['helpdetailtemplate'] = 'Usa um modelo visual diferente para exibir o artigo detalhado. Ele deve estar no diret&oacute;rio modules/News/templates.';
$lang['helpsortby'] = 'Organizar por.  As op&ccedil;&otilde;es s&atilde;o: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  O padr&atilde;o &eacute; &quot;news_date&quot;.';
$lang['helpsortasc'] = 'Organizar novos itens em ordem de data ascendente ao inv&eacute;s de descendente.';
$lang['helpdetailpage'] = 'P&aacute;gina para exibir a noticia detalhada. Pode ser o atalho da p&aacute;gina ou um ID. Usado para permitir que a pagina detalhada seja exibida num modelo visual diferente do resumo.';
$lang['helpshowarchive'] = 'Show only expired news articles.';
$lang['helpbrowsecat'] = 'Shows a browseable category list.';
$lang['helpaction'] = 'Override the default action.  Possible values are &#039;default&#039; to display the summary view, and &#039;fesubmit&#039; to display the frontend form for allowing users to submit news articles on the front end.';
$lang['help'] = '	<h3>O que isto faz?</h3>
	<p>Not&iacute;cias &eacute; um m&oacute;dulo para exibir eventos e not&iacute;cias no seu site, similar a um blog, mas com muito mais fun&ccedil;&otilde;es!.  Quando o m&oacute;dulo &eacute; instalado, uma p&aacute;gina de administra&ccedil;&atilde;o de Not&iacute;cias &eacute; adicionada ao menu de administradao e ir&aacute; permitir que voc&ecirc;s selecione ou adiocione uma categoria de not&iacute;cias. Uma vez criada ou selecionada, uma lista de itens de not&iacute;cias ser&aacute; exibida. Daqui, voc&ecirc; pode adicionar, editar ou deletar not&iacute;cias para esta categoria.</p>
	
<h3>Vari&aacute;veis de Modelo Visual</h3>
	<ul>
		<li><b>itemcount</b> - N&uacute;mero de not&iacute;cias a exibir.</li>
	</ul>
<h3>Seguran&ccedil;a</h3>
	<p>O usu&aacute;rio deve pertencer a um grupo com a permiss&atilde;o &#039;Modificar Not&iacute;cias&#039; a fim de adicionar, editar ou apagar Not&iacute;cias.</p>
	<p> Para adicionar, editar ou apagar Modelos Visuais, o usu&aacute;rio deve pertencer a um grupo com a permiss&atilde;o &#039;Modificar Modelos Visuais&#039;.</p>
	<p>Para editar as prefer&ecirc;ncias das not&iacute;cias globais, o usu&aacute;rio deve pertencer a um grupo com a permiss&atilde;o &#039;Modificar Prefer&ecirc;ncias do Site&#039;.</p>
	<h3>Como eu uso?</h3>
	<p>A maneira mais f&aacute;cil de usar-lo &eacute; em conjun&ccedil;&atilde;o com a tag cms_module. Isto ir&aacute; inserir o m&oacute;dulo dentro do seu Modelo Visual ou p&aacute;gina em qualquer lugar que voc&ecirc; quiser exibir as not&iacute;cias. O c&oacute;digo deve se parecer com algo como: <code>{cms_module module=&quot;news&quot; number=&quot;5&quot; category=&quot;beer&quot;</code>}</p>
<h3>Informa&ccedil;&atilde;o de Tradu&ccedil;&atilde;o</h3>
<p>Traduzido por Jos&eacute; Diogenes Silva</br>D&uacute;vidas e sugest&otilde;es: diogenescmsms@gmail.com</p>
';
$lang['utma'] = '156861353.3961599676465751000.1236885004.1236889412.1237485500.3';
$lang['utmz'] = '156861353.1237485500.3.3.utmcsr=ruimedeiros.com|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utmb'] = '156861353.1.10.1237485500';
$lang['utmc'] = '156861353';
?>